@@ -75,7 +75,7 @@ int main(int argc, char **argv)
         print_help_and_exit();
         break;
       case 's':
-        printf("%s -L%s/lib -lcomplearn\n", "-lz  -L/usr/lib -lgsl -lgslcblas -lm -lxml2 -Wl,--export-dynamic -lgobject-2.0 -lgmodule-2.0 -lglib-2.0   -lbz2 -ldl", fixup("${prefix}"));
+        printf("%s -L%s/lib -lcomplearn\n", "-lz  -L/usr/lib -lgsl -lgslcblas -lm -lxml2 -pthread -Wl,--export-dynamic -lgobject-2.0 -lgthread-2.0 -lgmodule-2.0 -lrt -lglib-2.0   -lbz2 -ldl", fixup("${prefix}"));
         break;
       case 'l':
         printf("-L%s/lib -lcomplearn\n", fixup("${prefix}"));
